pub type Snatchable2<T> = SnatchableInner<DestructibleResourceState<T>>;Expand description
A value that is mostly immutable but can be “snatched” if we need to destroy it early.
In order to safely access the underlying data, the device’s global snatchable lock must be taken. To guarantee it, methods take a read or write guard of that special lock.
Aliased Type
pub struct Snatchable2<T> {
value: UnsafeCell<DestructibleResourceState<T>>,
}Fields
value: UnsafeCell<DestructibleResourceState<T>>